
.. .. image:: https://readthedocs.org/projects/aws_console_url_search/badge/?version=latest
    :target: https://aws_console_url_search.readthedocs.io/index.html
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/aws_console_url_search-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/aws_console_url_search-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/aws_console_url_search-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/aws_console_url_search-project

.. image:: https://img.shields.io/pypi/v/aws_console_url_search.svg
    :target: https://pypi.python.org/pypi/aws_console_url_search

.. image:: https://img.shields.io/pypi/l/aws_console_url_search.svg
    :target: https://pypi.python.org/pypi/aws_console_url_search

.. image:: https://img.shields.io/pypi/pyversions/aws_console_url_search.svg
    :target: https://pypi.python.org/pypi/aws_console_url_search

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_console_url_search-project

------


.. .. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://aws_console_url_search.readthedocs.io/index.html

.. .. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://aws_console_url_search.readthedocs.io/py-modindex.html

.. .. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
    :target: https://aws_console_url_search.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/aws_console_url_search-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/aws_console_url_search-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/aws_console_url_search-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/aws_console_url_search#files


Welcome to ``aws_console_url_search`` Documentation
==============================================================================
``aws_console_url_search`` allows you to full-text search AWS services.


.. _install:

Install
------------------------------------------------------------------------------

``aws_console_url_search`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install aws_console_url_search

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade aws_console_url_search
